# Clement
[![PyPI version](https://badge.fury.io/py/clement.svg)](https://badge.fury.io/py/clement)
## GUI for Correlative Light and Electron Microscopy
A graphical program to correlate electron microscopy and fluorescent optical images of the same sample.

## Installation
The package is pure python, and the easiest way to install it is through PyPi with the following command:
```
$ pip install clement
```
We recommend create a separate environment using either `conda` or `virtualenv` to manage dependencies.

Further instructions are available in the Wiki [here](https://github.com/kartikayyer/Clement/wiki/installation).

## Tutorial
A guide with screenshots for semi-automatic alignment of FM and EM images based on observable features is also described on the [wiki](https://github.com/kartikayyer/Clement/wiki/tutorial-2D).

